"""This is the sample module for didiatic purpose only
    It is not advised to use this in production """


def print_lol(the_list):
    
    for each_item in the_list:
        if isinstance(each_item,list):
            print_lol(each_item)
        else:
            print(each_item)


