from distutils.core import setup

setup(
        name = 'nexter',
        version = '1.0.0',
        py_modules = ['nexter'],
        author = 'basileis',
        author_email = 'basileis@gmail.com',
        url = 'http://basileis.com',
        description = 'New module for didiatic purpose',
    )

